]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - command.c
rename struct dbtool to audio_file_selector
[paraslash.git] / command.c
index 3fe6e5db008a6d2cfdc767cbd8e04321ea739391..0fc385e980bff69f9ac7ead244ff514b2419644f 100644 (file)
--- a/command.c
+++ b/command.c
@@ -44,7 +44,7 @@ static unsigned char rc4_buf[2 * RC4_KEY_LEN];
 extern const char *status_item_list[NUM_STAT_ITEMS];
 extern struct misc_meta_data *mmd;
 extern struct gengetopt_args_info conf;
-extern struct dbtool dblist[];
+extern struct audio_file_selector dblist[];
 extern struct audio_format afl[];
 extern struct sender senders[];
 extern char *user_list;
@@ -63,7 +63,7 @@ static int com_stop(int, int, char **);
 static int com_pause(int, int, char **);
 static int com_next(int, int, char **);
 static int com_nomore(int, int, char **);
-static int com_cdt(int, int, char **);
+static int com_chs(int, int, char **);
 static int com_ff(int, int, char **);
 static int com_jmp(int, int, char **);
 static int com_sender(int, int, char **);
@@ -72,14 +72,14 @@ static int com_sender(int, int, char **);
 /* commands that are handled by the server itself */
 static struct server_command cmd_struct[] = {
 {
-.name = "cdt",
-.handler = com_cdt,
+.name = "chs",
+.handler = com_chs,
 .perms = DB_READ | DB_WRITE,
-.description = "change database tool",
-.synopsis = "cdt [name_of_new_dbtool]",
+.description = "change the current audio file selector",
+.synopsis = "chs [new_selector]",
 .help =
-"Deactivate current dbtool and activate name_of_new_dbtool. If no\n"
-"argument was given, print the current database tool.\n"
+"Shutdown the current selector and activate new_selector. If no\n"
+"argument was given, print the name of the current selector.\n"
 },
 
 {
@@ -732,7 +732,7 @@ static struct server_command *get_cmd_ptr(char *name, char **handler)
                                *handler = para_strdup("para_server"); /* server commands */
                        return cmd;
                }
/* not found, look for dbtool commands */
        mmd_lock();
        if (handler)
                *handler = make_message("the %s database tool", dblist[mmd->dbt_num].name);
@@ -848,7 +848,7 @@ static int com_pause(__unused int socket_fd, int argc, __unused char **argv)
        return 1;
 }
 
-static int com_cdt(int fd, int argc, char **argv)
+static int com_chs(int fd, int argc, char **argv)
 {
        int i, ret;
@@ -732,7 +732,7 @@ static struct server_command *get_cmd_ptr(char *name, char **handler)
                        return cmd;
                }
-       /* not found, look for dbtool commands */
+       /* not found, look for commands supported by the current selector */
        mmd_lock();
        if (handler)